#![cfg_attr(nightly, feature(option_unwrap_none))]
#![cfg_attr(nightly, feature(never_type))] 

#![allow(dead_code)]

#![cfg_attr(nightly, feature(test))] 

#[cfg(all(nightly, test))] extern crate test;

#[macro_use] extern crate log;

use async_trait::async_trait;
use serde::{
    Serialize, Deserialize,
};
use color_eyre::{
    eyre,
    Help,
    SectionExt,
};
use futures::{
    FutureExt as _,
    prelude::*,
};
use hex_literal::hex;
use lazy_static::lazy_static;

macro_rules! cfg_debug {
    (if {$($if:tt)*} else {$($else:tt)*}) => {
	{
	    #[cfg(debug_assertions)] {
		$($if)*
	    }
	    #[cfg(not(debug_assertions))] {
		$($else)*
	    }
	}
    };
    (if $if:expr) => {
	{
	    #[cfg(debug_assertions)] $if
	}
    };
    (else $else:expr) => {
	{
	    #[cfg(not(debug_assertions))] $else
	}
    };
}


mod ext;
use ext::*;
mod bytes;
mod suspend;

mod regex;
mod cache;

mod config;
mod tripcode;
mod identity;
mod post;
mod state;

mod html;
mod web;

#[tokio::main]
async fn main() -> Result<(), eyre::Report>{
    color_eyre::install()?;
    pretty_env_logger::init();

    trace!("Setting default config");

    config::set(Default::default());
    
    web::serve(Default::default()).await?;

    info!("Server shutdown gracefully");
    /*
    let mut vec = vec![vec![1, 0, 0],
		       vec![0, 0, 1]];
    let span = vec![vec![0, 1, 0],
			vec![1, 0, 1],
			vec![0, 1, 0]];
    
    for _ in 0..10000 {
	vec.insert_exact(1, span.iter().cloned());
}*/
    Ok(())
}
